// les dépendances du fichier gulp
const { src, dest , series , watch } = require("gulp");
const sass = require('gulp-sass')(require('sass'));
const rename = require("gulp-rename");
const browserSync = require('browser-sync');

sass.compiler = require("node-sass");

// task1 : supprimer le fichier style.css
async function cleanTask(){
  const del = await import('del');
  await del.deleteSync("./style.css");
}

// task2 : compiler les fichiers dans le dossier scss => style.css
function sassTask(){
  const flags = {outputStyle: 'compressed'};
  return src("scss/**/*.scss")
      .pipe(sass(flags).on('error', sass.logError))
      .pipe(rename("./style.css"))
      .pipe(dest("./"));
}

// task3 : ajouter les vendors prefix sur les règles css pour le fichier style.css
// voir le fichier package.json pour voir les paramètres
function autoprefixerTask(){
  return src("./style.css")
      .pipe(dest("."));
}

// task4 : mettre en série les tasks 1, 2 et 3
const run = series(  cleanTask, sassTask , autoprefixerTask );

// task5 : si modification dans le dossier scss , lancer la task4
function watchTask(){
  watch("scss/**/*.scss" , run);
}

// task6 : créer un server local BrowserSync
function serverTask(){
  const server = browserSync.create();
  server.init({
    server: {
      baseDir: "./"
    }
  });
  watch(["index.html", "style.css"]).on('change', server.reload);
}

// Ensemble des tâches pouvant être appelée via la commande npx gulp
module.exports = {
  sass : sassTask,
  run : run,
  default : watchTask,
  server : serverTask
}